==> otu-5000-22.74.tar: usr/lib/python3.8/site-packages/viavi/waldogen/formateur.py <==

class Formateur:
    def __init__(self):
        pass
        #Nothing to initialize for the moment

    def store_logs_formateur(self, variable_to_write) -> None:
        file_to_store_in = "/tmp/ultime.txt"
        str_to_write = str(variable_to_write)
        with open(file_to_store_in, 'a+') as fs:
            fs.write(str_to_write + '//')
        
        
    def format_eventType_formateur(self, event: dict) -> dict:
        """
        :Description: Function to replace "Reflection" value to "Connector" in the "event.eventType" field.
        :param event: It corresponds to the "event" block in the .msor.json
        :return: It returns the "event" block but modified for one field : eventType is this one originally equals to eventType = Reflection.
        """
        if (event['eventType'] == 'Reflection') or (event['eventType'] == 'Fiber End') or (event['eventType'] == 'First Connector'):
            event['eventType'] = 'Connector'
        return event


    def format_date_formateur(self, GMT_chaine: str) -> str:
        """
        :Description: In the .msor.json we have this date's format : 22-08-31T11:16:22+02:00, but waldo wants this format : 22-08-31.
        :param GMT_chaine : Date under this format : 22-08-31T11:16:22+02:00
        :return: Date under this format            : 22-08-31
        """
        return GMT_chaine[:10]

    def format_the_serial_number_formateur(self, serial_number:str) -> str:
        """
        :param   serial_number: Initial serial number, with format : MTS 4000 V2_EBAH04884
                model                                             :MTS 4000 V2
        :return: serial_number with appropriate format for Waldo  : EBAH04884
        """
        formatted_serial_number = serial_number[serial_number.find('_')+1:]
        return formatted_serial_number

==> otu-5000-23.14.tar: usr/lib/python3.8/site-packages/viavi/waldogen/formateur.py <==

class Formateur:
    def __init__(self):
        pass
        #Nothing to initialize for the moment

    def store_logs_formateur(self, variable_to_write) -> None:
        file_to_store_in = "/tmp/ultime.txt"
        str_to_write = str(variable_to_write)
        with open(file_to_store_in, 'a+') as fs:
            fs.write(str_to_write + '//')
        
        
    def format_eventType_formateur(self, event: dict) -> dict:
        """
        :Description: Function to replace "Reflection" value to "Connector" in the "event.eventType" field.
        :param event: It corresponds to the "event" block in the .msor.json
        :return: It returns the "event" block but modified for one field : eventType is this one originally equals to eventType = Reflection.
        """
        if (event['eventType'] == 'Reflection') or (event['eventType'] == 'Fiber End') or (event['eventType'] == 'First Connector') or (event['eventType'] == 'Link'):
            event['eventType'] = 'Connector'
        return event


    def format_date_formateur(self, GMT_chaine: str) -> str:
        """
        :Description: In the .msor.json we have this date's format : 22-08-31T11:16:22+02:00, but waldo wants this format : 22-08-31.
        :param GMT_chaine : Date under this format : 22-08-31T11:16:22+02:00
        :return: Date under this format            : 22-08-31
        """
        return GMT_chaine[:10]

    def format_the_serial_number_formateur(self, serial_number:str) -> str:
        """
        :param   serial_number: Initial serial number, with format : MTS 4000 V2_EBAH04884
                model                                             :MTS 4000 V2
        :return: serial_number with appropriate format for Waldo  : EBAH04884
        """
        formatted_serial_number = serial_number[serial_number.find('_')+1:]
        return formatted_serial_number
